@@ -23,7 +23,8 @@ class Todo:
             "D": TerminalOperations.foreground_color(int("0x4d",16)),
             "E": TerminalOperations.foreground_color(int("0x50",16)),
             "F": TerminalOperations.foreground_color(int("0x3e",16)),
-        }
+        },
+        "search_match": TerminalOperations.foreground_color(222),
     }
 
     def __init__(self, item, index,
@@ -38,7 +39,7 @@ class Todo:
         self.due_date       = due_date
         self.completed_date = completed_date
         self.colored        = self.highlight()
-        self.colored_length = TerminalOperations.length_ignoring_escapes(self.colored)
+        # self.colored_length = TerminalOperations.length_ignoring_escapes(self.colored)
 
     def update(self, item):
         self.raw            = item.strip()
@@ -49,7 +50,7 @@ class Todo:
         self.due_date       = Todos.due_date(item)
         self.completed_date = Todos.completed_date(item)
         self.colored        = self.highlight()
-        self.colored_length = TerminalOperations.length_ignoring_escapes(self.colored)
+        # self.colored_length = TerminalOperations.length_ignoring_escapes(self.colored)
 
     def __repr__(self):
         return repr({
@@ -77,21 +78,31 @@ class Todo:
                 colored = line_color + colored
 
             for context in self.contexts:
-                colored = colored.replace(context, "{}{}{}".format(
+                colored = colored.replace(context, "{0}{1}{2}".format(
                     colors["context"], context, line_color ))
 
             for project in self.projects:
-                colored = colored.replace(project, "{}{}{}".format(
+                colored = colored.replace(project, "{0}{1}{2}".format(
                     colors["project"], project, line_color ))
 
-            colored = colored.replace(self.creation_date, "{}{}{}".format(
+            colored = colored.replace(self.creation_date, "{0}{1}{2}".format(
                 colors["creation_date"], self.creation_date, line_color), 1)
 
-            colored = colored.replace("due:"+self.due_date, "{}{}{}".format(
+            colored = colored.replace("due:"+self.due_date, "{0}{1}{2}".format(
                 colors["due_date"], "due:"+self.due_date, line_color), 1)
 
         return colored
 
+    def highlight_search_matches(self, line=""):
+        colors = Todo.colors
+        colored = self.raw if line == "" else line
+        line_color = colors["foreground"]
+        if self.search_matches:
+            for match in self.search_matches:
+                colored = colored.replace(match, "{0}{1}{2}".format(
+                    colors["search_match"], match, line_color))
+        return colored
+
     def is_complete(self):
         if self.raw[0:2] == "x ":
             return True
@@ -102,8 +113,8 @@ class Todo:
 
     def complete(self):
         today = date.today()
-        self.raw = "x {} ".format(today) + self.raw
-        self.completed_date = "{}".format(today)
+        self.raw = "x {0} ".format(today) + self.raw
+        self.completed_date = "{0}".format(today)
 
     def incomplete(self):
         self.raw = re.sub(Todos._completed_regex, "", self.raw)
@@ -111,8 +122,8 @@ class Todo:
 
     def add_creation_date(self):
         if self.creation_date == "":
-            p = "({}) ".format(self.priority) if self.priority != "" else ""
-            self.update("{}{} {}".format(p, date.today(), self.raw.replace(p, "")))
+            p = "({0}) ".format(self.priority) if self.priority != "" else ""
+            self.update("{0}{1} {2}".format(p, date.today(), self.raw.replace(p, "")))
 
 
 class Todos:
@@ -267,6 +278,32 @@ class Todos:
     def filter_context_and_project(self, context, project):
         return [item for item in self.todo_items if project in item.projects and context in item.contexts]
 
+    def search(self, search_string):
+        search_string = re.escape(search_string)
+        # print(search_string)
+        ss = []
+        substrings = search_string.split("\\")
+        for index, substring in enumerate(substrings):
+            s = ".*?".join(substring)
+            # s.replace(" .*?", " ")
+            if 0 < index < len(substrings)-1:
+                s += ".*?"
+            ss.append(s)
+        # print(repr(ss))
+        search_string_regex  = '^.*('
+        search_string_regex += "\\".join(ss)
+        search_string_regex += ').*'
+        # print(search_string_regex)
+
+        r = re.compile(search_string_regex, re.IGNORECASE)
+        results = []
+        for t in self.todo_items:
+            match = r.search(t.raw)
+            if match:
+                t.search_matches = match.groups()
+                results.append(t)
+        return results
+
     quotes = [
         "What you really believe about the source of great performance thus becomes the foundation of all you will ever achieve -- Geoff Colvin, Talent is Overrated: What Really Separates World-Class Performers from Everybody Else",
         "Do not let your good ideas to spend your brain energy, do it with all the effort because the shadow of the success can become a reality only with hard work.  -- Isra",
